==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/invoice/NaposSellerInfo.java <==
package eleme.openapi.sdk.api.entity.invoice;

import eleme.openapi.sdk.api.entity.invoice.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class NaposSellerInfo{

    /**
     * 名称
     */
    private String name;
    public String getName() {
        return name;
    }
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * 纳税人识别号
     */
    private String taxPayerNum;
    public String getTaxPayerNum() {
        return taxPayerNum;
    }
    public void setTaxPayerNum(String taxPayerNum) {
        this.taxPayerNum = taxPayerNum;
    }
    
    /**
     * 注册地址
     */
    private String registerAddress;
    public String getRegisterAddress() {
        return registerAddress;
    }
    public void setRegisterAddress(String registerAddress) {
        this.registerAddress = registerAddress;
    }
    
    /**
     * 注册电话
     */
    private String registerPhone;
    public String getRegisterPhone() {
        return registerPhone;
    }
    public void setRegisterPhone(String registerPhone) {
        this.registerPhone = registerPhone;
    }
    
    /**
     * 开户行名称
     */
    private String bankName;
    public String getBankName() {
        return bankName;
    }
    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    
    /**
     * 开户行账号
     */
    private String bankAccount;
    public String getBankAccount() {
        return bankAccount;
    }
    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    
    /**
     * 收款人
     */
    private String payee;
    public String getPayee() {
        return payee;
    }
    public void setPayee(String payee) {
        this.payee = payee;
    }
    
    /**
     * 复核人
     */
    private String checker;
    public String getChecker() {
        return checker;
    }
    public void setChecker(String checker) {
        this.checker = checker;
    }
    
    /**
     * 操作员
     */
    private String clerk;
    public String getClerk() {
        return clerk;
    }
    public void setClerk(String clerk) {
        this.clerk = clerk;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/invoice/NaposSellerInfo.java <==
package eleme.openapi.sdk.api.entity.invoice;

import eleme.openapi.sdk.api.enumeration.invoice.*;
import eleme.openapi.sdk.api.entity.invoice.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class NaposSellerInfo{

    /**
     * 名称
     */
    private String name;
    public String getName() {
        return name;
    }
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * 纳税人识别号
     */
    private String taxPayerNum;
    public String getTaxPayerNum() {
        return taxPayerNum;
    }
    public void setTaxPayerNum(String taxPayerNum) {
        this.taxPayerNum = taxPayerNum;
    }
    
    /**
     * 注册地址
     */
    private String registerAddress;
    public String getRegisterAddress() {
        return registerAddress;
    }
    public void setRegisterAddress(String registerAddress) {
        this.registerAddress = registerAddress;
    }
    
    /**
     * 注册电话
     */
    private String registerPhone;
    public String getRegisterPhone() {
        return registerPhone;
    }
    public void setRegisterPhone(String registerPhone) {
        this.registerPhone = registerPhone;
    }
    
    /**
     * 开户行名称
     */
    private String bankName;
    public String getBankName() {
        return bankName;
    }
    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    
    /**
     * 开户行账号
     */
    private String bankAccount;
    public String getBankAccount() {
        return bankAccount;
    }
    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    
    /**
     * 收款人
     */
    private String payee;
    public String getPayee() {
        return payee;
    }
    public void setPayee(String payee) {
        this.payee = payee;
    }
    
    /**
     * 复核人
     */
    private String checker;
    public String getChecker() {
        return checker;
    }
    public void setChecker(String checker) {
        this.checker = checker;
    }
    
    /**
     * 操作员
     */
    private String clerk;
    public String getClerk() {
        return clerk;
    }
    public void setClerk(String clerk) {
        this.clerk = clerk;
    }
    
    /**
     * 纳税省份编码
     */
    private String provinceCode;
    public String getProvinceCode() {
        return provinceCode;
    }
    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }
    
}
